==> feathers-mongoose-casl-dashboard-1.3.2.tgz: package/es/Dashboard.js <==
var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { FeathersAdmin, listViews, docViews } from 'redux-admin';
import getListFields from './getListFields';
import _getDocFields from './getDocFields';
import getInitialValues from './getInitialValues';
import startCase from 'lodash/startCase';
// import {buildYup} from './utils/json-schema-to-yup/index';
import { buildYup } from 'json-schema-to-yup';
import cloneDeep from 'lodash/cloneDeep';
import { getDeepObjectValue } from 'validate.js';
import { LOCALS } from './local';
import { getFieldName } from './utils.js';

var index = function (_Component) {
  _inherits(index, _Component);

  function index(props) {
    _classCallCheck(this, index);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.getDocTitle = function (data) {
      var _this$props = _this.props,
          dashboardConfig = _this$props.dashboardConfig,
          url = _this$props.url;

      var localName = getDeepObjectValue(dashboardConfig, 'i18n.' + LOCALS.LANG_CODE + '.serviceNameOne');
      var name = localName || startCase(url);

      var _ref = dashboardConfig || {},
          docTitleField = _ref.docTitleField;

      if (data && data._id) {
        return name + ' ' + (data[docTitleField] || data.name || data.title || data._id);
      } else {
        return LOCALS.RENDER_NEW_DOC_NAME(name, data);
      }
    };

    _this.getDefaultOptions = function () {
      var populate = _this.props.populate;

      if (populate) {
        return {
          $populate: populate.join(','),
          '$sort[updatedAt]': -1
        };
      }
      return {
        '$sort[updatedAt]': -1
      };
    };

    _this.getFilterTitle = function (field) {
      _this.filtersNames = _this.filtersNames || {};
      _this.filtersNames[field.key] = _this.filtersNames[field.key] || getFieldName({ target: 'filters', lang: LOCALS.LANG_CODE, itemKey: field.key, dashboardConfig: _this.props.dashboardConfig });
      return _this.filtersNames[field.key];
    };

    _this.docFields = null;
    _this.listFields = null;
    _this.yup = null;
    return _this;
  }

  index.prototype.fixJsonSchemaRequires = function fixJsonSchemaRequires(jsonSchema) {
    var _schema = cloneDeep(jsonSchema);
    if (_schema.properties) {
      // remove hidden fields and fix required fields
      var required = jsonSchema.required || [];
      var fields = Object.keys(_schema.properties);
      var newProperties = {};
      fields.forEach(function (filedKey) {
        var field = _schema.properties[filedKey];
        var dashboard = getDeepObjectValue(field, 'meta.0.dashboard');
        if (dashboard && dashboard.allowNull) {
          field.type = [field.type, null];
        }
        if (field.type === 'object' && field.required) {
          required.push(filedKey);
          field.required.forEach(function (innerField) {
            return required.push(filedKey + '.' + innerField);
          });
        }
        if (dashboard && dashboard.hide) {
          return;
        }
        newProperties[filedKey] = field;
        var isRequired = required.includes(field);
        if (isRequired) {
          var fieldConfig = jsonSchema.properties[field];
          if (fieldConfig.type === 'string') {
            if (!fieldConfig.minLength) {
              _schema.properties[field] = Object.assign({}, _schema.properties[field], { minLength: 1 });
            }
          }
        }
      });
      _schema.properties = newProperties;
    }
    return _schema;
  };

  index.prototype.getJoiSchema = function getJoiSchema(jsonSchema) {
    if (this.yup) return this.yup;
    try {
      var _jsonSchema = this.fixJsonSchemaRequires(jsonSchema);
      var yup = buildYup(_jsonSchema);
      if (yup) {
        this.yup = yup;
      }
      return this.yup;
    } catch (error) {
      console.log('getJoiSchema error', error);
    }
    return this.yup;
  };

  index.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        url = _props.url,
        jsonSchema = _props.jsonSchema,
        dashboardConfig = _props.dashboardConfig,
        updateFields = _props.updateFields,
        createFields = _props.createFields,
        showBreadcrumb = _props.showBreadcrumb,
        syncWithUrl = _props.syncWithUrl,
        listTargetKeyPrefix = _props.listTargetKeyPrefix,
        dashboardData = _props.dashboardData,
        editAfterSaved = _props.editAfterSaved;

    if (!jsonSchema || !url) return '';
    this.joiSchema = this.joiSchema || this.getJoiSchema(jsonSchema);
    var defaultOptions = this.getDefaultOptions();
    var localName = getDeepObjectValue(dashboardConfig, 'i18n.' + LOCALS.LANG_CODE + '.serviceName');
    return React.createElement(
      'div',
      { className: 'screen-' + url },
      React.createElement(FeathersAdmin, {
        title: localName || url,
        defaultOptions: defaultOptions,
        getDocTitle: this.getDocTitle,
        url: url,
        listTargetKeyPrefix: listTargetKeyPrefix,
        lang: LOCALS.LANG_CODE,
        rtl: LOCALS.LANG_DIR === 'rtl',
        list: React.createElement(listViews.Table, {
          lang: LOCALS.LANG_CODE,
          rtl: LOCALS.LANG_DIR === 'rtl',
          getFilterTitle: this.getFilterTitle
          // renderOnTop={(props) => {
          //   console.log({props})
          //   return (
          //     <div className='onTopBoxRow'>
          //       <div className='onTopBox'>
          //         <div className='onTopBoxValue__number'>{props.count || 0}</div>
          //         <div className='onTopBox__text'>Total</div>
          //       </div>
          //       <div className='onTopBox primary'>
          //         <div className='onTopBoxValue__number'><Icon type="user-add" /></div>
          //         <div className='onTopBox__text'>Add</div>
          //       </div>
          //     </div>

          //   )
          // }}
          , getColumns: function getColumns(props) {
            _this2.listFields = _this2.listFields || getListFields(props, jsonSchema, dashboardConfig);
            return _this2.listFields;
          },
          rowSelection: this.props.rowSelection,
          onRow: this.props.onRow
        }),
        doc: React.createElement(docViews.SimpleDoc, {
          lang: LOCALS.LANG_CODE,
          rtl: LOCALS.LANG_DIR === 'rtl',
          immutableKeys: ['_id', 'updatedAt', 'createdAt'],
          getDocFields: function getDocFields(props) {
            var isNewDoc = props.isNewDoc;
            _this2.newDocFields = _this2.newDocFields || isNewDoc ? _getDocFields(props, jsonSchema, { createFields: createFields, updateFields: updateFields }, dashboardData, '', dashboardConfig) : null;
            _this2.editDocFields = _this2.editDocFields || !isNewDoc ? _getDocFields(props, jsonSchema, { createFields: createFields, updateFields: updateFields }, dashboardData, '', dashboardConfig) : null;
            return isNewDoc ? _this2.newDocFields : _this2.editDocFields;
          },
          newDocInitialValues: getInitialValues(jsonSchema),
          validationSchema: this.joiSchema,
          getHeadersBeforeSubmit: function getHeadersBeforeSubmit(_ref2) {
            var dataToSend = _ref2.dataToSend;

            var allFields = Object.keys(dataToSend);
            var hasFile = allFields.some(function (item) {
              var val = dataToSend[item];
              return val && (typeof val === 'undefined' ? 'undefined' : _typeof(val)) === 'object' && val instanceof File;
            });
            if (hasFile) return { 'content-type': 'multipart/form-data' };
            return null;
          },
          parseDataBeforeSubmit: function parseDataBeforeSubmit(_ref3) {
            var dataToSend = _ref3.dataToSend;

            var allFields = Object.keys(dataToSend);
            var hasFile = allFields.some(function (item) {
              var val = dataToSend[item];
              return val && (typeof val === 'undefined' ? 'undefined' : _typeof(val)) === 'object' && val instanceof File;
            });
            if (!hasFile) return dataToSend;else {
              var formData = new FormData();
              allFields.forEach(function (fieldKey) {
                var value = dataToSend[fieldKey];
                if ((typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object') {
                  var isFile = value instanceof File;
                  if (isFile) {
                    formData.append(fieldKey, value);
                  } else {
                    formData.append(fieldKey, JSON.stringify(value));
                  }
                } else {
                  formData.append(fieldKey, value);
                }
              });
              return formData;
            }
          }
        }),
        roleConfig: {
          canRead: true,
          canCreate: this.props.canCreate,
          canUpdate: this.props.canUpdate,
          canDelete: this.props.canDelete
        },
        showBreadcrumb: showBreadcrumb,
        syncWithUrl: syncWithUrl,
        editAfterSaved: editAfterSaved
      })
    );
  };

  return index;
}(Component);

export default index;

==> feathers-mongoose-casl-dashboard-1.3.3.tgz: package/es/Dashboard.js <==
var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import { FeathersAdmin, listViews, docViews } from 'redux-admin';
import startCase from 'lodash/startCase';
// import {buildYup} from './utils/json-schema-to-yup/index';
import { buildYup } from 'json-schema-to-yup';
import cloneDeep from 'lodash/cloneDeep';
import { getDeepObjectValue } from 'validate.js';
import getInitialValues from './getInitialValues';
import _getDocFields from './getDocFields';
import getListFields from './getListFields';
import { LOCALS } from './local';
import { getFieldName } from './utils.js';

var index = function (_Component) {
  _inherits(index, _Component);

  function index(props) {
    _classCallCheck(this, index);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.getDocTitle = function (data) {
      var _this$props = _this.props,
          dashboardConfig = _this$props.dashboardConfig,
          url = _this$props.url;

      var localName = getDeepObjectValue(dashboardConfig, 'i18n.' + LOCALS.LANG_CODE + '.serviceNameOne');
      var name = localName || startCase(url);

      var _ref = dashboardConfig || {},
          docTitleField = _ref.docTitleField;

      if (data && data._id) {
        return name + ' ' + (data[docTitleField] || data.name || data.title || data._id);
      }
      return LOCALS.RENDER_NEW_DOC_NAME(name, data);
    };

    _this.getDefaultOptions = function () {
      var populate = _this.props.populate;

      if (populate) {
        return {
          $populate: populate.join(','),
          '$sort[updatedAt]': -1
        };
      }
      return {
        '$sort[updatedAt]': -1
      };
    };

    _this.getFilterTitle = function (field) {
      _this.filtersNames = _this.filtersNames || {};
      _this.filtersNames[field.key] = _this.filtersNames[field.key] || getFieldName({ target: 'filters', lang: LOCALS.LANG_CODE, itemKey: field.key, dashboardConfig: _this.props.dashboardConfig });
      return _this.filtersNames[field.key];
    };

    _this.docFields = null;
    _this.listFields = null;
    _this.yup = null;
    return _this;
  }

  index.prototype.fixJsonSchemaRequires = function fixJsonSchemaRequires(jsonSchema) {
    var _schema = cloneDeep(jsonSchema);
    if (_schema.properties) {
      // remove hidden fields and fix required fields
      var required = jsonSchema.required || [];
      var fields = Object.keys(_schema.properties);
      var newProperties = {};
      fields.forEach(function (filedKey) {
        var field = _schema.properties[filedKey];
        var dashboard = getDeepObjectValue(field, 'meta.0.dashboard');
        if (dashboard && dashboard.allowNull) {
          field.type = [field.type, null];
        }
        if (field.type === 'object' && field.required) {
          required.push(filedKey);
          field.required.forEach(function (innerField) {
            return required.push(filedKey + '.' + innerField);
          });
        }
        if (dashboard && dashboard.hide) {
          return;
        }
        newProperties[filedKey] = field;
        var isRequired = required.includes(field);
        if (isRequired) {
          var fieldConfig = jsonSchema.properties[field];
          if (fieldConfig.type === 'string') {
            if (!fieldConfig.minLength) {
              _schema.properties[field] = _extends({}, _schema.properties[field], { minLength: 1 });
            }
          }
        }
      });
      _schema.properties = newProperties;
    }
    return _schema;
  };

  index.prototype.getJoiSchema = function getJoiSchema(jsonSchema) {
    if (this.yup) return this.yup;
    try {
      var _jsonSchema = this.fixJsonSchemaRequires(jsonSchema);
      var yup = buildYup(_jsonSchema);
      if (yup) {
        this.yup = yup;
      }
      return this.yup;
    } catch (error) {
      console.log('getJoiSchema error', error);
    }
    return this.yup;
  };

  index.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        url = _props.url,
        jsonSchema = _props.jsonSchema,
        dashboardConfig = _props.dashboardConfig,
        updateFields = _props.updateFields,
        createFields = _props.createFields,
        showBreadcrumb = _props.showBreadcrumb,
        syncWithUrl = _props.syncWithUrl,
        listTargetKeyPrefix = _props.listTargetKeyPrefix,
        dashboardData = _props.dashboardData,
        editAfterSaved = _props.editAfterSaved,
        customRenderField = _props.customRenderField,
        customElements = _props.customElements;

    if (!jsonSchema || !url) return '';
    this.joiSchema = this.joiSchema || this.getJoiSchema(jsonSchema);
    var defaultOptions = this.getDefaultOptions();
    var localName = getDeepObjectValue(dashboardConfig, 'i18n.' + LOCALS.LANG_CODE + '.serviceName');
    return React.createElement(
      'div',
      { className: 'screen-' + url },
      React.createElement(FeathersAdmin, {
        title: localName || url,
        defaultOptions: defaultOptions,
        getDocTitle: this.getDocTitle,
        url: url,
        listTargetKeyPrefix: listTargetKeyPrefix,
        lang: LOCALS.LANG_CODE,
        rtl: LOCALS.LANG_DIR === 'rtl',
        list: React.createElement(listViews.Table, {
          lang: LOCALS.LANG_CODE,
          rtl: LOCALS.LANG_DIR === 'rtl',
          getFilterTitle: this.getFilterTitle
          // renderOnTop={(props) => {
          //   console.log({props})
          //   return (
          //     <div className='onTopBoxRow'>
          //       <div className='onTopBox'>
          //         <div className='onTopBoxValue__number'>{props.count || 0}</div>
          //         <div className='onTopBox__text'>Total</div>
          //       </div>
          //       <div className='onTopBox primary'>
          //         <div className='onTopBoxValue__number'><Icon type="user-add" /></div>
          //         <div className='onTopBox__text'>Add</div>
          //       </div>
          //     </div>

          //   )
          // }}
          , getColumns: function getColumns(props) {
            _this2.listFields = _this2.listFields || getListFields(props, jsonSchema, dashboardConfig);
            return _this2.listFields;
          },
          rowSelection: this.props.rowSelection,
          onRow: this.props.onRow
        }),
        doc: React.createElement(docViews.SimpleDoc, {
          lang: LOCALS.LANG_CODE,
          rtl: LOCALS.LANG_DIR === 'rtl',
          immutableKeys: ['_id', 'updatedAt', 'createdAt'],
          getDocFields: function getDocFields(props) {
            var isNewDoc = props.isNewDoc;

            _this2.newDocFields = _this2.newDocFields || isNewDoc ? _getDocFields(props, jsonSchema, { createFields: createFields, updateFields: updateFields }, dashboardData, '', dashboardConfig, customRenderField, customElements) : null;
            _this2.editDocFields = _this2.editDocFields || !isNewDoc ? _getDocFields(props, jsonSchema, { createFields: createFields, updateFields: updateFields }, dashboardData, '', dashboardConfig, customRenderField, customElements) : null;
            return isNewDoc ? _this2.newDocFields : _this2.editDocFields;
          },
          newDocInitialValues: getInitialValues(jsonSchema),
          validationSchema: this.joiSchema,
          getHeadersBeforeSubmit: function getHeadersBeforeSubmit(_ref2) {
            var dataToSend = _ref2.dataToSend;

            var allFields = Object.keys(dataToSend);
            var hasFile = allFields.some(function (item) {
              var val = dataToSend[item];
              return val && (typeof val === 'undefined' ? 'undefined' : _typeof(val)) === 'object' && val instanceof File;
            });
            if (hasFile) return { 'content-type': 'multipart/form-data' };
            return null;
          },
          parseDataBeforeSubmit: function parseDataBeforeSubmit(_ref3) {
            var dataToSend = _ref3.dataToSend;

            var allFields = Object.keys(dataToSend);
            var hasFile = allFields.some(function (item) {
              var val = dataToSend[item];
              return val && (typeof val === 'undefined' ? 'undefined' : _typeof(val)) === 'object' && val instanceof File;
            });
            if (!hasFile) return dataToSend;

            var formData = new FormData();
            allFields.forEach(function (fieldKey) {
              var value = dataToSend[fieldKey];
              if ((typeof value === 'undefined' ? 'undefined' : _typeof(value)) === 'object') {
                var isFile = value instanceof File;
                if (isFile) {
                  formData.append(fieldKey, value);
                } else {
                  formData.append(fieldKey, JSON.stringify(value));
                }
              } else {
                formData.append(fieldKey, value);
              }
            });
            return formData;
          }
        }),
        roleConfig: {
          canRead: true,
          canCreate: this.props.canCreate,
          canUpdate: this.props.canUpdate,
          canDelete: this.props.canDelete
        },
        showBreadcrumb: showBreadcrumb,
        syncWithUrl: syncWithUrl,
        editAfterSaved: editAfterSaved
      })
    );
  };

  return index;
}(Component);

export default index;
